@@ -1,5 +1,11 @@
 package Genealogy::ObituaryDailyTimes::DB;
 
+=head1
+
+Genealogy::ObituaryDailyTimes::DB
+
+=cut
+
 # Author Nigel Horne: njh@bandsman.co.uk
 # Copyright (C) 2015-2022, Nigel Horne
 
@@ -366,6 +372,9 @@ sub selectall_hash {
 	if(!$self->{no_entry}) {
 		$query .= ' ORDER BY entry';
 	}
+	if(!wantarray) {
+		$query .= ' LIMIT 1';
+	}
 	if($self->{'logger'}) {
 		if(defined($query_args[0])) {
 			$self->{'logger'}->debug("selectall_hash $query: ", join(', ', @query_args));
